package org.greenstone.gatherer.mem;
/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
import javax.swing.tree.DefaultTreeModel;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.mem.MEMNode;
import org.greenstone.gatherer.msm.MetadataSet;
import org.greenstone.gatherer.util.SynchronizedTreeModelTools;
/**
 * @author John Thompson, Greenstone Digital Library, University of Waikato
 * @version 2.3
 */
public class MEMModel 
	 extends DefaultTreeModel {

	 public MEMModel() {
		  super(new MEMNode());
	 }

	 public void add(MEMNode parent, Object object, int type) {
		  if(parent == null) {
				parent = (MEMNode) root;
		  }
		  MEMNode new_node = new MEMNode(type, object, null);
		  SynchronizedTreeModelTools.insertNodeInto(this, parent, new_node);
	 }

	 public MEMNode getProfileNode() {
		  MEMNode node = (MEMNode) root;
		  return (MEMNode) node.getChildAt(node.getChildCount() - 1);
	 }

	 public void remove(String name, int type) {
		  MEMNode current = (MEMNode) root;
		  for(int i = 0; i < current.getChildCount(); i++) {
				MEMNode child = (MEMNode) current.getChildAt(i);
				if(child.toString().equals(name) && type == MEMNode.SET) {
					 // Place on AWT event thread to avoid errors.
					 SynchronizedTreeModelTools.removeNodeFromParent(this, child);
					 return;
				}
				// This may be the profiler root node, in which case we descend into its children if we're looking for collection file matches. 
				else if(type == MEMNode.COLLECTION && child.getType() == MEMNode.PROFILER) {
					 for(int j = 0; j < child.getChildCount(); j++) {
						  MEMNode inner_child = (MEMNode) child.getChildAt(j);
						  if(inner_child.toString().equals(name)) {
								// Place on AWT event thread to avoid errors.
								SynchronizedTreeModelTools.removeNodeFromParent(this, inner_child);
								return;
						  }
					 }
				}
				// If this is a set and we are looking for an element, then iterate through its children. Can't really do this recursively.
				else if(type == MEMNode.ELEMENT && child.getType() == MEMNode.SET) {
					 for(int j = 0; j < child.getChildCount(); j++) {
						  MEMNode inner_child = (MEMNode) child.getChildAt(j);
						  if(inner_child.toString().equals(name)) {
								// Place on AWT event thread to avoid errors.
								SynchronizedTreeModelTools.removeNodeFromParent(this, inner_child);
								return;
						  }
					 }
				}
		  }
	 }
}
